==> kara-uc-1.2.27.tgz: package/src/kara-uc/components/UCMedal/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import {Scroll,Modal} from 'karaui'
import 'kara-module-tost/lib/index.css'
import tost,{errorTost} from "kara-module-tost";
import Card from './Card/index'
import StudyCard from './studyCard/index'


import { Tabs } from 'antd';
import { toJS } from 'mobx';
const { TabPane } = Tabs;

@inject('UCMedalStore', 'ConfigStore')
@observer
class UCInfo extends Component{
    constructor(props) {
        super(props)
        this.state={
            years:[],
        }
    }
    componentDidMount(){
        this.props.ConfigStore.config.httpAgent.get('/medal/mine/list').then(
          res => {
            if(res && res.resultCode && res.resultCode === '000000') {
              this.props.UCMedalStore.getMineList(res)
            }
            else {
              tost({type:'error',msg:'获取用户信息失败',time:4})
            }
          }
        )
     this.studyList()
    }
    studyList=()=>{
         // 计算距离2019年的年份
         let myDate = new Date();       
         let thisYear = myDate.getFullYear();
         let section = thisYear - 2009; 
         let arrYear = [];
         for(var i = 0;i<=section;i++){
             arrYear.push(thisYear--)
         }
           // 学习勋章单独接口
           this.props.ConfigStore.config.httpAgent.post('/medal/mine/study/list',{years:arrYear}).then(
            res => {
              if(res && res.resultCode && res.resultCode === '000000') {
                this.props.UCMedalStore.getStudyList(res)
                this.setState({arrYear})
              }
              else {
                tost({type:'error',msg:'获取用户信息失败',time:4})
              }
            }
          )
    }
    render(){
        const {UCMedalStore} = this.props;
        const {arrYear}=this.state
        return (
            <div className={css.UCMedal} style={{width:'100%',height:'100%',paddingRight:'0px'}}>
                <Scroll>
                    <div>
                        {
                            UCMedalStore.mineList?UCMedalStore.mineList.map((o,i)=>{
                                return (<Card card= {o} Modal={Modal} {...this.props}  key={i}/>)})
                            :null
                        } 
                
                        {
                            // 学习勋章单独接口
                            UCMedalStore.studyList?
                              <StudyCard card= {toJS(UCMedalStore.studyList)}  Modal={Modal} {...this.props} arrYear={arrYear}/>
                            :null
                        }

                    </div>
                </Scroll>
            </div>
        )
    }
}

export default UCInfo

==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCMedal/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import {Scroll,Modal} from 'karaui'
import 'kara-module-tost/lib/index.css'
import tost,{errorTost} from "kara-module-tost";
import Card from './Card/index'
import StudyCard from './studyCard/index'


import { Tabs } from 'antd';
import { toJS } from 'mobx';
const { TabPane } = Tabs;

@inject('UCMedalStore', 'ConfigStore')
@observer
class UCInfo extends Component{
    constructor(props) {
        super(props)
        this.state={
            years:[],
        }
    }
    componentDidMount(){
        this.props.ConfigStore.config.httpAgent.get('/medal/mine/list').then(
          res => {
            if(res && res.resultCode && res.resultCode === '000000') {
              this.props.UCMedalStore.getMineList(res)
            }
            else {
              tost({type:'error',msg:'获取用户信息失败',time:4})
            }
          }
        )
        this.props.ConfigStore.config.httpAgent.get('/account/getCurrentAccountCard').then(
            res => {
              if (res && res.resultCode && res.resultCode === '000000') {
                let hireDay=res.employeeCardInfo.hireDay
                let date = new Date(hireDay.replace(/-/g, "/")).getFullYear()
                 // 计算距离2019年或者入职时间的年份  
                let thisYear = new Date().getFullYear();
                let section=date>2019?thisYear - date:thisYear - 2019
                let arrYear = [];
                for(var i = 0;i<=section;i++){
                    arrYear.push(thisYear--)
                }
                this.studyList(arrYear)
              }
              else {
                tost({type: 'error', msg: '获取用户信息失败', time: 4})
              }
            }
          )
    }
    studyList=(arrYear)=>{
           // 学习勋章单独接口
           this.props.ConfigStore.config.httpAgent.post('/medal/mine/study/list',{years:arrYear}).then(
            res => {
              if(res && res.resultCode && res.resultCode === '000000') {
                this.props.UCMedalStore.getStudyList(res)
                this.setState({arrYear})
              }
              else {
                tost({type:'error',msg:'获取用户信息失败',time:4})
              }
            }
          )
    }
    render(){
        const {UCMedalStore} = this.props;
        const {arrYear}=this.state
        return (
            <div className={css.UCMedal} style={{width:'100%',height:'100%',paddingRight:'0px'}}>
                <Scroll>
                    <div>
                        {
                            UCMedalStore.mineList?UCMedalStore.mineList.map((o,i)=>{
                                return (<Card card= {o} Modal={Modal} {...this.props}  key={i}/>)})
                            :null
                        } 
                
                        {
                            // 学习勋章单独接口
                            UCMedalStore.studyList?
                              <StudyCard card= {toJS(UCMedalStore.studyList)}  Modal={Modal} {...this.props} arrYear={arrYear}/>
                            :null
                        }

                    </div>
                </Scroll>
            </div>
        )
    }
}

export default UCInfo
